@@ -2,7 +2,7 @@ import time
 
 import openai
 
-from cli.core import ensure_api_key, icase_contains, chatgpt_response
+from cli.core import ensure_api_key, icase_contains, chatgpt_response, get_env
 
 
 def main():
@@ -10,6 +10,8 @@ def main():
     chatgpt-cli [api_key]
     """
 
+    history_size = int(get_env('HISTORY_SIZE', '3'))
+
     openai.api_key = ensure_api_key(prompt=True)
 
     print('Welcome to the ChatGPT command-line interface\n')
@@ -39,8 +41,8 @@ def main():
 
             chat_history.append(message)
             chat_history.append({'role': 'assistant', 'content': response})
-            if len(chat_history) > 4:
-                chat_history.pop(0)
+            if len(chat_history) >= (history_size + 1) * 2:
+                chat_history = chat_history[2:]
 
             print('\nAI: ', end='')
             for char in response:
